@@ -18,7 +18,7 @@ __docformat__ = "restructuredtext en"
 
 from logilab.common.decorators import monkeypatch
 
-from cubicweb.web import formwidgets, stdmsgs
+from cubicweb_web import formwidgets, stdmsgs
 
 from cubicweb_bootstrap import monkeypatch_default_value
 
