@@ -10,7 +10,7 @@ __docformat__ = "restructuredtext en"
 from logilab.common.decorators import monkeypatch
 from six.moves import range
 
-from cubicweb.web.views import baseviews
+from cubicweb_web.views import baseviews
 
 baseviews.ListView.listtag = 'ul'
 
