@@ -8,7 +8,7 @@
 
 __docformat__ = "restructuredtext en"
 
-from cubicweb.web import component
+from cubicweb_web import component
 
 from cubicweb_bootstrap import monkeypatch_default_value
 
