@@ -16,7 +16,7 @@ from logilab.common.decorators import monkeypatch
 from logilab.mtconverter import xml_escape
 
 from cubicweb import BadConnectionId
-from cubicweb.web.views import debug
+from cubicweb_web.views import debug
 
 
 def dict_to_html(w, dict):
@@ -72,7 +72,7 @@ def call(self, **kwargs):
     w(u'<tr><th>%s</th><td>%s</td></tr>' % (
         _('data directory url'), req.datadir_url))
     w(u'</table>')
-    from cubicweb.web.application import SESSION_MANAGER
+    from cubicweb_web.application import SESSION_MANAGER
     if SESSION_MANAGER is not None and req.user.is_in_group('managers'):
         sessions = SESSION_MANAGER.current_sessions()
         w(u'<h3>%s</h3>' % _('opened web sessions'))
