@@ -8,7 +8,7 @@
 __docformat__ = "restructuredtext en"
 
 from logilab.common.decorators import monkeypatch
-from cubicweb.web.views import editforms
+from cubicweb_web.views import editforms
 
 
 @monkeypatch(editforms.EditionFormView)
