@@ -10,7 +10,7 @@ __docformat__ = "restructuredtext en"
 from logilab.common.decorators import monkeypatch
 
 from cubicweb.utils import UStringIO
-from cubicweb.web import formfields
+from cubicweb_web import formfields
 
 
 @monkeypatch(formfields.FileField)
