@@ -23,7 +23,7 @@ from logilab.common.decorators import monkeypatch
 
 from cubicweb import tags
 from cubicweb.utils import support_args
-from cubicweb.web.views import formrenderers
+from cubicweb_web.views import formrenderers
 
 
 @monkeypatch(formrenderers.EntityCompositeFormRenderer)
