@@ -18,8 +18,8 @@
 __docformat__ = "restructuredtext en"
 
 
-from cubicweb.web.views.forms import FieldsForm
-from cubicweb.web.views.autoform import AutomaticEntityForm
+from cubicweb_web.views.forms import FieldsForm
+from cubicweb_web.views.autoform import AutomaticEntityForm
 
 # Forms
 FieldsForm.needs_js += ('cubes.bootstrap.edition.js',)
