@@ -11,7 +11,7 @@ from logilab.common.decorators import monkeypatch
 from logilab.mtconverter import xml_escape
 
 from cubicweb import tags, __version__ as cwver
-from cubicweb.web import formwidgets
+from cubicweb_web import formwidgets
 
 from cubicweb_bootstrap import CW_325
 
