@@ -10,10 +10,10 @@ from logilab.common.decorators import monkeypatch
 
 from logilab.mtconverter import xml_escape
 
-from cubicweb.view import View
-from cubicweb.web.component import NavigationComponent
+from cubicweb_web.view import View
+from cubicweb_web.component import NavigationComponent
 
-from cubicweb.web.views.navigation import (NextPrevNavigationComponent,
+from cubicweb_web.views.navigation import (NextPrevNavigationComponent,
                                            SortedNavigation,
                                            PageNavigation,
                                            PageNavigationSelect)
