@@ -6,7 +6,7 @@
 """
 __docformat__ = "restructuredtext en"
 
-from cubicweb.web.views.reledit import AutoClickAndEditFormView
+from cubicweb_web.views.reledit import AutoClickAndEditFormView
 AutoClickAndEditFormView._addzone = u' <span class="glyphicon glyphicon-plus"></span>'
 AutoClickAndEditFormView._deletezone = u' <span class="glyphicon glyphicon-remove"></span>'
 AutoClickAndEditFormView._editzone = u' <span class="glyphicon glyphicon-pencil"></span>'
