@@ -10,7 +10,7 @@ __docformat__ = "restructuredtext en"
 
 from logilab.common.decorators import monkeypatch
 
-from cubicweb.web.views import tableview
+from cubicweb_web.views import tableview
 
 tableview.TableLayout.cssclass = 'listing table table-bordered table-condensed'
 
